summaryrefslogtreecommitdiffstats
path: root/src/usr/hwpf/test/hwpftest.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/hwpf/test/hwpftest.H')
-rw-r--r--src/usr/hwpf/test/hwpftest.H4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/usr/hwpf/test/hwpftest.H b/src/usr/hwpf/test/hwpftest.H
index 21e26ca2c..e482f4caa 100644
--- a/src/usr/hwpf/test/hwpftest.H
+++ b/src/usr/hwpf/test/hwpftest.H
@@ -189,11 +189,11 @@ public:
*/
void testHwpf2()
{
- // Call a test hardware procedure
errlHndl_t l_err = NULL;
// Set processor chip to NULL. The target is not used by this HWP
TARGETING::Target* l_pTarget = NULL;
+ TARGETING::targetService().masterProcChipTargetHandle(l_pTarget);
// Create a FAPI Target and invoke the hwpTestError HWP. The HWP
// returns an error to test out error handling
OpenPOWER on IntegriCloud
@@ -189,11 +189,11 @@ public:
errlHndl_t l_err = NULL;
- // Set processor chip to NULL. The target is not used by this HWP
+ // Get the master processor chip
TARGETING::Target* l_pTarget = NULL;